==> org.eclipse.emf.emfstore.client.ui.source_1.4.0.v20140912-0421.jar: org/eclipse/emf/emfstore/internal/client/ui/handlers/DeleteProjectOnServerHandler.java <==
/*******************************************************************************
 * Copyright (c) 2012-2013 EclipseSource Muenchen GmbH and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * ovonwesen
 * emueller
 ******************************************************************************/
package org.eclipse.emf.emfstore.internal.client.ui.handlers;

import org.eclipse.emf.emfstore.internal.client.model.ServerInfo;
import org.eclipse.emf.emfstore.internal.client.ui.controller.UIDeleteRemoteProjectController;
import org.eclipse.emf.emfstore.internal.server.model.ProjectInfo;

/**
 * Handler for deleting a remote project.<br/>
 * It is assumed that the user previously has selected a {@link ProjectInfo} instance.
 * 
 * @author ovonwesen
 * @author emueller
 * 
 */
public class DeleteProjectOnServerHandler extends AbstractEMFStoreHandler {

	/**
	 * 
	 * {@inheritDoc}
	 * 
	 * @see org.eclipse.emf.emfstore.internal.client.ui.handlers.AbstractEMFStoreHandler#handle()
	 */
	@Override
	public void handle() {
		ProjectInfo projectInfoSelection = requireSelection(ProjectInfo.class);
		ServerInfo serverInfo = (ServerInfo) projectInfoSelection.eContainer();
		new UIDeleteRemoteProjectController(getShell(), serverInfo, projectInfoSelection).execute();
	}
}

==> org.eclipse.emf.emfstore.client.ui.source_1.9.0.v20170530-0703.jar: org/eclipse/emf/emfstore/internal/client/ui/handlers/DeleteProjectOnServerHandler.java <==
/*******************************************************************************
 * Copyright (c) 2012-2013 EclipseSource Muenchen GmbH and others.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * ovonwesen
 * emueller
 ******************************************************************************/
package org.eclipse.emf.emfstore.internal.client.ui.handlers;

import org.eclipse.emf.emfstore.internal.client.model.ServerInfo;
import org.eclipse.emf.emfstore.internal.client.ui.controller.UIDeleteRemoteProjectController;
import org.eclipse.emf.emfstore.internal.server.model.ProjectInfo;

/**
 * Handler for deleting a remote project.<br/>
 * It is assumed that the user previously has selected a {@link ProjectInfo} instance.
 *
 * @author ovonwesen
 * @author emueller
 *
 */
public class DeleteProjectOnServerHandler extends AbstractEMFStoreHandler {

	/**
	 *
	 * {@inheritDoc}
	 *
	 * @see org.eclipse.emf.emfstore.internal.client.ui.handlers.AbstractEMFStoreHandler#handle()
	 */
	@Override
	public void handle() {
		final ProjectInfo projectInfoSelection = requireSelection(ProjectInfo.class);
		final ServerInfo serverInfo = (ServerInfo) projectInfoSelection.eContainer();
		new UIDeleteRemoteProjectController(getShell(), serverInfo, projectInfoSelection).execute();
	}
}
